"use strict";
// a helper function
// accepts 4 parameters
// source file, modifier file, operation, target file
// it reads from the source and modifier files
// then it performs the operation on those two sets of data
// finally, it stores the result of the operation in the target file
//
// resolves to true if everything went well
// resolves to false otherwise
// displays an error if it encounters a condition that will cause it to resolve to false
Object.defineProperty(exports, "__esModule", { value: true });
const read_write_file_1 = require("../../../core-providers/file-services/read-write-file");
const ora_1 = require("ora");
function sourceModifierOperation(source, modifier, target, operation, options, opName) {
    ora_1.promise(_sourceModifierOperation(source, modifier, target, operation, options), 'Running ' + opName);
}
exports.sourceModifierOperation = sourceModifierOperation;
function _sourceModifierOperation(source, modifier, target, operation, options) {
    let startingJson;
    let modifierToUse;
    let afterOperationApplied;
    // source file read, and main return statement
    return read_write_file_1.readJsonLdFile(source)
        .then(res => {
        if (!res) {
            return false;
        }
        else {
            startingJson = res;
            return readModifierFile();
        }
    });
    // modifier file read
    function readModifierFile() {
        return read_write_file_1.readJsonLdFile(modifier)
            .then(res => {
            if (!res) {
                return false;
            }
            else {
                modifierToUse = res;
                return performOperation();
            }
        });
    }
    // now perform the main JSON-LD operation
    // note: we need to wrap the es6-promise (OldPromise) in a TS promise for the compiler to be happy
    function performOperation() {
        return operation(startingJson, modifierToUse, options)
            .then(res => {
            afterOperationApplied = res;
            return writeTargetFile();
        })
            .catch(err => false);
    }
    // target file write
    function writeTargetFile() {
        return read_write_file_1.writeJsonLdFile(target, afterOperationApplied)
            .then(_ => true)
            .catch(() => false);
    }
}
//# sourceMappingURL=source-mod-op-target.js.map