"use strict";
// validates target file
// the target file must either exist, or be created without error
// resolves true exactly when the target file is validated
// calls displayError if it is going to return false
Object.defineProperty(exports, "__esModule", { value: true });
const filename_and_title_model_1 = require("../../../models/filename-and-title-model");
const file_error_handler_1 = require("../file-error-handler/file-error-handler");
const fs_1 = require("fs");
const util_1 = require("util");
const confirm_overwrite_1 = require("./confirm-overwrite");
const openFile = util_1.promisify(fs_1.open);
function validateTargetFile(file = filename_and_title_model_1.newFileNameTitle(), defaultTargetFile = filename_and_title_model_1.newFileNameTitle()) {
    let fileNameToTest;
    // attempt to find principal, then default filename
    // if neither one exists, display an error and terminate
    if (file.name) {
        fileNameToTest = file.name;
    }
    if (!fileNameToTest && (defaultTargetFile && defaultTargetFile.name)) {
        fileNameToTest = defaultTargetFile.name;
    }
    else if (!fileNameToTest && (!defaultTargetFile || !defaultTargetFile.name)) {
        file_error_handler_1.displayError("No file specified." /* NO_FILE_SPECIFIED */, file.title || defaultTargetFile.title || '');
        return Promise.resolve(false);
    }
    // name has been found
    // now check whether file can be opened
    // first get user confirmation to overwrite existing target file, if there is one
    if (fs_1.existsSync(fileNameToTest)) {
        return confirm_overwrite_1.confirmOverwrite(fileNameToTest); // file exists, get user confirmation via keyboard input
    }
    else {
        return openFile(fileNameToTest, 'w') // file does not exist, return true if opened successfully
            .then(res => true)
            .catch(err => {
            file_error_handler_1.displayError("Cannot create file." /* CANNOT_CREATE_FILE */, fileNameToTest); // report error otherwise
            return false;
        });
    }
}
exports.validateTargetFile = validateTargetFile;
//# sourceMappingURL=validate-target-file.js.map