"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const util_1 = require("util");
const file_error_handler_1 = require("./file-error-handler/file-error-handler");
// read from or write to a file
const readFilePromise = util_1.promisify(fs_1.readFile);
const writeFilePromise = util_1.promisify(fs_1.writeFile);
function readJsonLdFile(fileName) {
    return readFilePromise(fileName)
        .then(buf => JSON.parse(buf.toString()))
        .catch(err => {
        file_error_handler_1.displayError("Cannot read from file." /* CANNOT_READ_FROM_FILE */, fileName);
        return null;
    });
}
exports.readJsonLdFile = readJsonLdFile;
// write to a file
// resolves to true if the write went well
// resolves to false otherwise
// calls displayError if resolving to false
function writeJsonLdFile(fileName, data) {
    return writeFilePromise(fileName, JSON.stringify(data))
        .then(_ => true)
        .catch(err => {
        file_error_handler_1.displayError("Cannot write to file." /* CANNOT_WRITE_TO_FILE */, fileName);
        return false;
    });
}
exports.writeJsonLdFile = writeJsonLdFile;
//# sourceMappingURL=read-write-file.js.map